 .. Licensed to the Apache Software Foundation (ASF) under one
    or more contributor license agreements.  See the NOTICE file
    distributed with this work for additional information
    regarding copyright ownership.  The ASF licenses this file
    to you under the Apache License, Version 2.0 (the
    "License"); you may not use this file except in compliance
    with the License.  You may obtain a copy of the License at

 ..   http://www.apache.org/licenses/LICENSE-2.0

 .. Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied.  See the License for the
    specific language governing permissions and limitations
    under the License.

ERD Schema of the FAB Database
''''''''''''''''''''''''''''''

Here is the current database schema diagram for the FAB auth manager provider tables.

.. warning::

   The ER diagram shows the snapshot of the database structure valid for version |version| and it
   should be treated as an internal detail. It might be changed at any time and you should not directly
   access the database to retrieve information from it or modify the data.
   The main purpose of this diagram is to help with troubleshooting and understanding of the
   internal FAB DB architecture in case you have any problems with the database — for example
   when dealing with problems with migrations. See also :doc:`migrations-ref` for
   list of detailed database migrations.

.. This image is automatically generated during documentation build by the ``generate_erd`` Sphinx extension.

.. image:: img/fab_erd.svg
